#!/bin/bash

fix_grub_conf()
{
    echo "Fix grub.conf file"
    grub_conf=$_root_path/boot/efi/EFI/BOOT/GRUB.CONF
    cp "$grub_conf" "$grub_conf.apprecovery" || return 1
    naked_boot_dev=$(lsblk -o KNAME,UUID | grep -e $new_efi_device | awk '{print $1}' | grep -Eo [a-z]+)
    let boot_num=$(echo ${naked_boot_dev:2:3} | od -An -t uC | cut -d ' ' -f3)-97
    let "boot_num=$boot_num+1"
    sed -i "s|root (hd[0-9]\+,[0-9]\+)|root = (hd$boot_num,$1)|g" $grub_conf || return 1
    old_hd=`cat $grub_conf | grep "splashimage"`
    new_hd=`echo $old_hd | sed -e "s|(hd[0-9],[0-9])|(hd1,1)|g"`
    sed -i "s|$old_hd|$new_hd|g" $grub_conf || return 1
    sed -i "s|device (hd[0-9]\+)|device (hd$boot_num)|g" $grub_conf || return 1
    rm -rf "$grub_conf.apprecovery"
}

gen_net_devices()
{
    local root_path=$1
    [ -z $root_path ] && return 1
    net_devices=($(ls $root_path/sys/class/net/))
    for device in ${net_devices[@]}; do
        case "$device" in
            lo) continue ;;
            *) touch $root_path/etc/sysconfig/network-scripts/ifcfg-$device
               ifcfg_file=$root_path/etc/sysconfig/network-scripts/ifcfg-$device
               uuid_net_dev=$(uuidgen $network_devices)
echo -n "TYPE=\"Ethernet\"
PROXY_METHOD=\"none\"
BROWSER_ONLY=\"no\"
BOOTPROTO=\"dhcp\"
DEFROUTE=\"yes\"
IPV4_FAILURE_FATAL=\"no\"
IPV6INIT=\"yes\"
IPV6_AUTOCONF=\"yes\"
IPV6_DEFROUTE=\"yes\"
IPV6_FAILURE_FATAL=\"no\"
IPV6_ADDR_GEN_MODE=\"stable-privacy\"
NAME=\"$device\"
UUID=\"$uuid_net_dev\"
DEVICE=\"$device\"
ONBOOT=\"yes\"
" > $ifcfg_file
            ;;
        esac
    done
}

gen_net_devices $_root_path

if check_efi "$_boot_path" "$fstab_file"; then
    efi_dev_number=`get_efi_dev_number $efi_volume`
    remount_efi_device $_root_path || die "remount_efi_device" "$?"
    fix_fstab || die "fix_fstab" "$?"
    copy_efi_files || die "copy_efi_files" "$?"
    run_efibootmgr $efi_dev_number \\\\EFI\\\\BOOT\\\\${efi_file[0]} || die "run_efibootmgr" "$?"
    update_initrd $_root_path $distribution || die "update_initrd" "$?"
else
    if [ "$distribution" == "centos6" ]; then
        echo "FIX RHEL 6"
        fix_fstab || die "fix_fstab" "$?"
        resolve_hd || die "resolve_hd" "$?"
        patch_device_map $grub_dir/device.map || die "patch_device_map" "$?"
        patch_menu_lst $grub_dir/menu.lst || die "patch_menu_lst" "$?"
        update_initrd $_root_path $distribution || die "update_initrd" "$?"
    else
        echo "FIX RHEL 7"
        fix_fstab || die "fix_fstab" "$?"
        install_grub2 || die "install_grub2" "$?"
        update_initrd $_root_path $distribution || die "update_initrd" "$?"
    fi
fi
