#!/bin/bash

fix_net_and_display() 
{
    if [ -f $_root_path/etc/udev/rules.d/70-persistent-net.rules ] ; then
        echo "Removing udev rule that breaks network"
        mv $_root_path/etc/udev/rules.d/70-persistent-net.rules $_root_path/etc/udev/rules.d/70-persistent-net.rules.bak
    fi

    echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
    echo "There is a high possiblity that after boot GUI"
    echo "won't start. To fix this please run:"
    echo "'sudo /usr/sbin/sax2 -a' and then run 'sudo gdm'"
    echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
}

fix_elilo_conf()
{
    echo "Fix elilo.conf file ..."
    elilo_conf=$_root_path/boot/efi/efi/BOOT/elilo.conf
    cp $elilo_conf $elilo_conf.apprecovery || return 1
    uuid=$(lsblk $root_dev -no UUID)
    sed -i "s|root = [a-zA-Z0-9/_-]\+|root = /dev/disk/by-uuid/$uuid|g" $elilo_conf && rm -rf "$elilo_conf.apprecovery" || return 1
}

copy_init_files()
{
    echo "Coping init files to $_root_path/boot/efi/efi/BOOT/"
    local initrd_version=`cat $elilo_conf | grep -o -m1 "initrd = [a-zA-Z0-9/_-\+]\+" | awk '{print $3}'`
    vmlinuz_version=`echo "$initrd_version" | sed "s|initrd-||g"`
    vmlinuz_version="vmlinuz-$vmlinuz_version"
    cp $_root_path/boot/$initrd_version $_root_path/boot/efi/efi/BOOT/$initrd_version || return 1
    cp $_root_path/boot/$vmlinuz_version $_root_path/boot/efi/efi/BOOT/$vmlinuz_version || return 1
}

if check_efi "$_boot_path" "$fstab_file"; then
    efi_dev_number=`get_efi_dev_number $efi_volume`
    get_grub_efi_path $distribution || die "get_grub_efi_path" "$?"
    remount_efi_device $_root_path || die "remount_efi_device" "$?"
    copy_efi_files || die "copy_efi_files" "$?"
    fix_fstab || die "fix_fstab" "$?"
    if [[ "${efi_file[@]}" =~ "elilo.efi" ]]; then
        fix_elilo_conf || die "fix_elilo_conf" "$?"
        run_efibootmgr $efi_dev_number \\\\EFI\\\\BOOT\\\\${efi_file[0]} || die "run_efibootmgr" "$?"
        copy_init_files || die "copy_init_files" "$?"
    else
        if [[ $distribution == "sles11" || $distribution == "sled11" ]]; then
            echo "Installing grub"
            install_grub || die "run_efibootmgr" "$?"
        elif [[ $distribution == "sles12" || $distribution == "sled12" ]]; then
            echo "Install grub2"
            install_grub2 || die "install_grub2" "$?"
        elif [[ $distribution == "sles15" || $distribution == "sled15" ]]; then
            echo "Install grub2"
            install_grub2 || die "install_grub2" "$?"
        fi
    fi
    update_initrd $_root_path $distribution || die "update_initrd" "$?"
    fix_net_and_display || die "fix_net_and_display" "$?"
else
    if [[ $distribution == "sles11" || $distribution == "sled11" ]]; then
        echo "FIX SLES 11"
        fix_fstab || die "fix_fstab" "$?"
        resolve_hd || die "resolve_hd" "$?"
        patch_device_map $grub_dir/device.map || die "patch_device_map" "$?"
        patch_menu_lst $grub_dir/menu.lst "$distribution" || die "patch_menu_lst" "$?"
        update_initrd $_root_path $distribution || die "update_initrd" "$?"
        fix_net_and_display || die "fix_net_and_display" "$?"
    elif [[ $distribution == "sles12" || $distribution == "sled12" ]]; then
        echo "FIX SLES 12";
        fix_fstab || die "fix_fstab" "$?"
        install_grub2 || die "install_grub2" "$?"
        update_initrd $_root_path $distribution || die "update_initrd" "$?"
    elif [[ $distribution == "sles15" || $distribution == "sled15" ]]; then
        echo "FIX SLES 15";
        fix_fstab || die "fix_fstab" "$?"
        install_grub2 || die "install_grub2" "$?"
        update_initrd $_root_path $distribution || die "update_initrd" "$?"
    fi
fi

