#!/usr/bin/env python

import re
import sys
import os
from os.path import normpath, dirname, isabs
from os.path import join as pjoin
import subprocess as sp

def fix_link(fpath):
    """ if fpath is a link, get absolute path of the destination, otherwise return fpath back """
    if os.path.islink(fpath):
        lpath = os.readlink(fpath)
        if os.path.isabs(lpath): return lpath
        else: return normpath( pjoin(dirname(fpath), lpath) )
    return fpath

def get_mounts():
    """ returns a dictionary: {<device>: <mountpoint>} """
    outp = sp.Popen(['mount'], stdout=sp.PIPE).stdout.readlines()

    res = dict()
    patt = re.compile(r'^(?P<dev>/dev/.*) on (?P<mnt>.*) type ')
    for line in outp:
        m = patt.match(line)
        if m is None: continue
        res[ fix_link( m.group('dev') ) ] = m.group('mnt')

    return res

def main():
    mounts = get_mounts()

    mntpoint = ''
    for vol in mounts:
        try:
            mntpoint = mounts[vol]

            dspath = pjoin(mntpoint, '.blksnap/data')
            if not os.path.exists(dspath):
                continue

            ret = sp.call(['bsctl', '--check-data-store', vol])
            if ret != 0:
                os.unlink(dspath)
                print 'Datastore ' + dspath + ' fixed'
            else:
                print 'Datastore on ' + mntpoint + ' is ok'

        except Exception, e:
            sys.stderr.write(str(e) + '\n')


if __name__ == '__main__': main()
