#!/bin/bash

fix_fstab() {
    file=$1
    echo "Removing not existing devices from fstab. A backup will be created at /etc/fstab_virtual_export.bak"

    cp $file "$file"_virtual_export.bak

    for d in `cat $file | cut -d ' ' -f1 | cut -d \$'\t' -f1 | sed 's|"||g' | sed 's|^ *||g' | grep "^/"` ; do
        if ! ls $d 1>/dev/null 2>&1 ; then
            echo "Device: $d not found. Removing it from fstab.";
            sed -i '\|.*'"$d"'.*|d' $file ;
        fi
    done

    for d in `cat $file | cut -d ' ' -f1 | cut -d \$'\t' -f1 | sed 's|"||g' | sed 's|^ *||g' | grep "^[Uu][Uu][Ii][Dd]" | cut -d '=' -f2` ; do
        if ! ls /dev/disk/by-uuid/$d 1>/dev/null 2>&1 ; then
            echo "Device: $d not found. Removing it from fstab.";
            sed -i '\|.*'"$d"'.*|d' $file ;
        fi
    done
}

check_sudo() {
    [ "`whoami`" != "root" ] && 
    {
        echo "This script must be executed with root privileges"
        exit 1
    }
}

check_sudo

_fstab_files=""

while getopts 'f:h' opt ; do
    case $opt in
        f) _fstab_files="$OPTARG"
            break;;
        h) echo "Usage: -f <path_to_fstab_file>"
            break;;
    esac
done

if [ -z $_fstab_files ]; then
    for p in `mount | cut -d ' ' -f3` ; do
        `ls $p/etc/fstab 1>/dev/null 2>&1` && _fstab_files+="$p/etc/fstab "
        `ls $p/fstab 1>/dev/null 2>&1` && _fstab_files+="$p/fstab "
    done
fi

if [ -z $_fstab_files ] ; then
    echo "No fstab file was found, please specify it manualy with -f option"
    exit 1
fi

for f in $_fstab_files ; do
    fix_fstab "$f"
done
