#!/bin/bash

# set -x

error ()
{
	echo "Error: $1"
	exit 1
}

help()
{
    echo "grubinstall.sh <deviceName> <mountPoint> <drivePath> "
    echo "Parameters: "
    echo "deviceName: Partition device path which includind /boot"
    echo "           folder (grub entry point)"
    echo "mountPoint: The partition mount point. Only / and /boot"
    echo "           mount points are allowed."
    echo "drivePath:  Device path to hard disk in which the grub "
    echo "           entry point should be written"

    exit 1
}

[ x$1 != x"" ] || help

[ ! -e "/mnt" ] && {
	mkdir /mnt || error "cannot create the directory"  
}

if [ x$2 == x"/" ]; then
	echo "Mounting $1 partition to /mnt"
	mount $1 /mnt || error "mount $1 failed"
	if [ ! -d /mnt/boot ]; then
		 error "boot dir was not found in mounted partition"
	fi
	#executing grub-install to write an entry point to MBR
	echo "Installing grub entry point" 
	grub-install --boot-directory=/mnt/boot $3 || error "failed to write grub entry point to MBR"
	echo "unmounting partition $1" 
	umount $1 || error "unmounting failed"
elif [ x$2 == x"/boot" ]; then
	echo "Mounting $1 partition ot /mnt"
	mount $1 || error "mount $1 failed"
	echo "Installing grub entry point" 
	grub-install --boot-directory=/mnt $3 || error "failed to write grub entry point to MBR"
	echo "unmounting partition $1"
	umount $1
else
	echo "Error in parameters, mount point should be /boot or /"
fi
