#!/bin/bash

# D-34915: to prevent processing snapshot device
# with udev rules (probe, create uuid, btrfs scan),
# we have to avoid probe this device.
# The only place where is can be done - skip probing
# in 60-persistent-storage.rules

# This script tries to install skip-rule into
# /etc/udev/rules.d/60-persistent-storage.rules

ETC_FILE=/etc/udev/rules.d/60-persistent-storage.rules
LIB_FILE=/lib/udev/rules.d/60-persistent-storage.rules
BAK_SUFFIX=apprecovery-backup

write_snap_rule() {
    cat <<EOR >> $1
# APPRECOVERY-SNAP-SKIP
# skip processing snapshot AND nbd device
KERNEL=="sbd*", OPTIONS="last_rule", GOTO="persistent_storage_end"
KERNEL=="nbd*", OPTIONS="last_rule", GOTO="persistent_storage_end"

EOR
}

if [ -r $ETC_FILE ]; then
    if grep -q APPRECOVERY-SNAP-SKIP $ETC_FILE; then
        # we have already modified this file
        exit 0
    fi
    # backup original file and install new rule at top of
    mv $ETC_FILE $ETC_FILE.$BAK_SUFFIX
    write_snap_rule $ETC_FILE
    cat $ETC_FILE.$BAK_SUFFIX >> $ETC_FILE
else
    # install new rule at top of original file
    write_snap_rule $ETC_FILE
    cat $LIB_FILE >> $ETC_FILE
fi

/sbin/udevadm control --reload
true

